==> metrics-broker-0.0.3.tgz: package/instruments/timer.js <==
/**
 * This file implements basic timer functionality for JavaScript programs
 * that use the metrics broker.
 *
 * Example usage:
 *
 * require('metrics-broker/instruments').Timer;
 *
 * var name = 'serviceTime';
 * var dimensions = { cust: 'custA', ... };
 * var t = new Timer(name, dimensions);
 * t.start();
 * // do some stuff
 * t.stop();
 *
 * See the README for more information on names and dimensions.
 */

var types = require('../broker').types;
var client = require('../broker').client;


/**
 * Create a new timer object.
 *
 * @constructor
 * @param {String} name The name of the timer.
 * @param {Object} dimensions The dimensions of the timer.  May be null,
 *  if no dimensions are desired.
 */
var Timer = module.exports = function Timer(name, dimensions) {
  if (! name) {
    throw new Error('No name specified');
  }
  if (dimensions && (typeof dimensions !== 'object')) {
    throw new Error('Dimensions must be an object');
  }
  this.name = name;
  this.dimensions = dimensions;
  this.startTime = null;
};


/**
 * Start the timer.
 *
 * @param {Boolean} reset Resets the timer's start time.  If this is false or
 *  unset, start() is idempotent (successive calls to start() without an
 *  intervening stop() will have no impact on the measurement).
 */
Timer.prototype.start = function start(reset) {
  if (this.startTime && !reset) {
    return;
  }
  this.startTime = Date.now();
};


/**
 * Stop the timer and record the value to an underlying histogram in the
 * broker.
 *
 * @param {Function(String)} callback A callback to be invoked after the
 *  message has been sent.  Most code can safely omit this.
 */
Timer.prototype.stop = function stop(callback) {
  client.send(types.HISTOGRAM, 'UPDATE', this.name, this.dimensions, 
      (Date.now() - this.startTime) / 1000, callback);
  this.startTime = null;
};


/** 
 * Clears the underlying histogram in the broker.
 *
 * @param {Function(String)} callback A callback to be invoked after the
 *  message has been sent.  Most code can safely omit this.
 */
Timer.prototype.clear = function clear(callback) {
  client.send(types.HISTOGRAM, 'CLEAR', this.name, this.dimensions, null,
      callback);
};

==> metrics-broker-0.2.0.tgz: package/instruments/timer.js <==
/**
 * This file implements basic timer functionality for JavaScript programs
 * that use the metrics broker.
 *
 * Example usage:
 *
 * require('metrics-broker/instruments').Timer;
 *
 * var name = 'serviceTime';
 * var dimensions = { cust: 'custA', ... };
 * var t = new Timer(name, dimensions);
 * t.start();
 * // do some stuff
 * t.stop();
 *
 * See the README for more information on names and dimensions.
 */

var types = require('../broker').types;
var Client = require('../broker').Client;


/**
 * Create a new timer object.
 *
 * @constructor
 * @param {String} name The name of the timer.
 * @param {Object} dimensions The dimensions of the timer.  May be null,
 *  if no dimensions are desired.
 */
var Timer = module.exports = function Timer(name, dimensions) {
  if (! name) {
    throw new Error('No name specified');
  }
  if (dimensions && (typeof dimensions !== 'object')) {
    throw new Error('Dimensions must be an object');
  }
  this.name = name;
  this.dimensions = dimensions;
  this.startTime = null;
};


/**
 * Start the timer.
 *
 * @param {Boolean} reset Resets the timer's start time.  If this is false or
 *  unset, start() is idempotent (successive calls to start() without an
 *  intervening stop() will have no impact on the measurement).
 */
Timer.prototype.start = function start(reset) {
  if (this.startTime && !reset) {
    return;
  }
  this.startTime = Date.now();
};


/**
 * Stop the timer and record the value to an underlying histogram in the
 * broker.
 *
 * @param {Function(String)} callback A callback to be invoked after the
 *  message has been sent.  Most code can safely omit this.
 */
Timer.prototype.stop = function stop(callback) {
  if (this.startTime === null) {
    throw new Error('timer stop() called before start()');
  }
  Client.send(types.HISTOGRAM, 'UPDATE', this.name, this.dimensions, 
      (Date.now() - this.startTime) / 1000, callback);
  this.startTime = null;
};


/** 
 * Clears the underlying histogram in the broker.
 *
 * @param {Function(String)} callback A callback to be invoked after the
 *  message has been sent.  Most code can safely omit this.
 */
Timer.prototype.clear = function clear(callback) {
  Client.send(types.HISTOGRAM, 'CLEAR', this.name, this.dimensions, null,
      callback);
};
